Django-AWS-Mail
===============

:Info: A Django email backend for Amazon's Simple Email Service (SES) and views + signals for Amazon's Simple Notification Service (SNS).

:Author: Bas van Gaalen (http://github.com/webtweakers)


.. image:: https://badge.fury.io/py/django-aws-mail.svg
    :target: https://badge.fury.io/py/django-aws-mail
